# MENACE

A reproduction of M.E.N.A.C.E. the "Matchbox Enabled Noughts And Crosses Engine" in Python 3.10.

## Installation

To install the program, simply run
```bash
pip install MENACE_ANN
```

And to run the program simply type
```bash
menace_ann
```
